pub struct OrderIdentity {
pub instrument_id: InstrumentId,
pub strategy_id: StrategyId,
pub order_side: OrderSide,
pub order_type: OrderType,
}Expand description
Order identity context stored at submission time, used by the WS dispatch task to produce proper order events without Cache access.
These fields are immutable for the lifetime of an order and are used to construct proper order events (OrderAccepted, OrderFilled, etc.) instead of execution reports.
Fields
instrument_id: InstrumentIdstrategy_id: StrategyIdorder_side: OrderSideorder_type: OrderTypeTrait Implementations
Sourceimpl Clone for OrderIdentity
impl Clone for OrderIdentity
Sourcefn clone(&self) -> OrderIdentity
fn clone(&self) -> OrderIdentity
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for OrderIdentity
impl RefUnwindSafe for OrderIdentity
impl Send for OrderIdentity
impl Sync for OrderIdentity
impl Unpin for OrderIdentity
impl UnsafeUnpin for OrderIdentity
impl UnwindSafe for OrderIdentity